diff --git a/asdf.asd b/asdf.asd
index 973ed29ae75e8023ff1174c8a7bd695bab336af7..f59cf333e60be5d30dd3363688142ec38a6417bf 100644
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.24.3" ;; to be automatically updated by bin/bump-revision
+  :version "2.25" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")
diff --git a/debian/changelog b/debian/changelog
index b6bae24be5c7dbb7e7aa8893bccd06e644120470..ed0f0694be4ba9b7670eb0c72822a42170240b18 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,3 +1,11 @@
+cl-asdf (2:2.25-1) unstable; urgency=low
+
+  * Lispworks: avoid professional edition functions in personal edition.
+  * CormanLisp: improve support a little bit.
+  * Exports: don't export utilities anymore. Please use asdf-utils.
+
+ -- Francois-Rene Rideau <fare@tunes.org>  Thu, 27 Sep 2012 18:35:21 -0400
+
 cl-asdf (2:2.24-1) unstable; urgency=low
 
   * ACL: handle SMP vs non-SMP builds in Allegro 9.0
diff --git a/test/compile-asdf.lisp b/test/compile-asdf.lisp
index 8dc651f047ab0491277198738d238c75ce81ff25..76f0f2bdc94a71ea182e22ac195dacd7f9773671 100644
--- a/test/compile-asdf.lisp
+++ b/test/compile-asdf.lisp
@@ -20,6 +20,7 @@
         (ignore-errors (load *asdf-fasl*)))
    (leave-lisp "Reusing previously-compiled ASDF" 0))
   (t
+   #+clisp (load-asdf-lisp)
    (let ((tmp (make-pathname :name "asdf-tmp" :defaults *asdf-fasl*)))
      (ensure-directories-exist *asdf-fasl*)
      (multiple-value-bind (result warnings-p errors-p)
diff --git a/asdf.lisp b/asdf.lisp
index 10eb0c369cbaebe7cbc582aa30d52897f8c7f26b..13061c39d1ed4571ad160284e40023dd208f68e8 100644
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
 ;;; This is ASDF 2.24.3: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
@@ -118,7 +118,7 @@
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.24.3")
+         (asdf-version "2.25")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
-;;; This is ASDF 2.24.3: Another System Definition Facility.
+;;; This is ASDF 2.25: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome: